@@ -51,7 +51,7 @@ func Test_eventLoop_gracefulExit(t *testing.T) {
 		t.Cleanup(testBus.Close)
 
 		finalEvent := partybus.Event{
-			Type: event.VulnerabilityScanningFinished,
+			Type: event.CLIExit,
 		}
 
 		worker := func() <-chan error {
@@ -183,7 +183,7 @@ func Test_eventLoop_unsubscribeError(t *testing.T) {
 		t.Cleanup(testBus.Close)
 
 		finalEvent := partybus.Event{
-			Type: event.VulnerabilityScanningFinished,
+			Type: event.CLIExit,
 		}
 
 		worker := func() <-chan error {
@@ -252,7 +252,7 @@ func Test_eventLoop_handlerError(t *testing.T) {
 		t.Cleanup(testBus.Close)
 
 		finalEvent := partybus.Event{
-			Type:  event.VulnerabilityScanningFinished,
+			Type:  event.CLIExit,
 			Error: fmt.Errorf("unable to create presenter"),
 		}
 
@@ -377,7 +377,7 @@ func Test_eventLoop_uiTeardownError(t *testing.T) {
 		t.Cleanup(testBus.Close)
 
 		finalEvent := partybus.Event{
-			Type: event.VulnerabilityScanningFinished,
+			Type: event.CLIExit,
 		}
 
 		worker := func() <-chan error {
