@@ -8,8 +8,8 @@ import (
 	"github.com/stretchr/testify/require"
 
 	"github.com/anchore/go-testutils"
+	"github.com/anchore/grype/grype/presenter/internal"
 	"github.com/anchore/grype/grype/presenter/models"
-	"github.com/anchore/syft/syft/source"
 )
 
 var update = flag.Bool("update", false, "update the *.golden files for cyclonedx presenters")
@@ -17,8 +17,8 @@ var update = flag.Bool("update", false, "update the *.golden files for cyclonedx
 func TestCycloneDxPresenterImage(t *testing.T) {
 	var buffer bytes.Buffer
 
-	matches, packages, context, metadataProvider, _, _ := models.GenerateAnalysis(t, source.ImageScheme)
-	sbom := models.SBOMFromPackages(t, packages)
+	matches, packages, context, metadataProvider, _, _ := internal.GenerateAnalysis(t, internal.ImageSource)
+	sbom := internal.SBOMFromPackages(t, packages)
 	pb := models.PresenterConfig{
 		Matches:          matches,
 		Packages:         packages,
@@ -42,16 +42,16 @@ func TestCycloneDxPresenterImage(t *testing.T) {
 	var expected = testutils.GetGoldenFileContents(t)
 
 	// remove dynamic values, which are tested independently
-	actual = models.Redact(actual)
-	expected = models.Redact(expected)
+	actual = internal.Redact(actual)
+	expected = internal.Redact(expected)
 
 	require.JSONEq(t, string(expected), string(actual))
 }
 
 func TestCycloneDxPresenterDir(t *testing.T) {
 	var buffer bytes.Buffer
-	matches, packages, ctx, metadataProvider, _, _ := models.GenerateAnalysis(t, source.DirectoryScheme)
-	sbom := models.SBOMFromPackages(t, packages)
+	matches, packages, ctx, metadataProvider, _, _ := internal.GenerateAnalysis(t, internal.DirectorySource)
+	sbom := internal.SBOMFromPackages(t, packages)
 	pb := models.PresenterConfig{
 		Matches:          matches,
 		Packages:         packages,
@@ -76,8 +76,8 @@ func TestCycloneDxPresenterDir(t *testing.T) {
 	var expected = testutils.GetGoldenFileContents(t)
 
 	// remove dynamic values, which are tested independently
-	actual = models.Redact(actual)
-	expected = models.Redact(expected)
+	actual = internal.Redact(actual)
+	expected = internal.Redact(expected)
 
 	require.JSONEq(t, string(expected), string(actual))
 }
