@@ -197,6 +197,10 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 							SearchedBy: CPEParameters{
 								Namespace: "nvd:cpe",
 								CPEs:      []string{"cpe:2.3:*:activerecord:activerecord:3.7.5:rando4:*:re:*:rails:*:*"},
+								Package: CPEPackageParameter{
+									Name:    "activerecord",
+									Version: "3.7.5",
+								},
 							},
 							Found: CPEResult{
 								CPEs:              []string{"cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*"},
@@ -247,6 +251,10 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 									"cpe:2.3:*:activerecord:activerecord:3.7.3:rando4:*:re:*:rails:*:*",
 								},
 								Namespace: "nvd:cpe",
+								Package: CPEPackageParameter{
+									Name:    "activerecord",
+									Version: "3.7.3",
+								},
 							},
 							Found: CPEResult{
 								CPEs:              []string{"cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*"},
@@ -280,6 +288,10 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 							SearchedBy: CPEParameters{
 								CPEs:      []string{"cpe:2.3:*:activerecord:activerecord:3.7.3:rando1:*:ra:*:ruby:*:*"},
 								Namespace: "nvd:cpe",
+								Package: CPEPackageParameter{
+									Name:    "activerecord",
+									Version: "3.7.3",
+								},
 							},
 							Found: CPEResult{
 								CPEs:              []string{"cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:ruby:*:*"},
@@ -325,6 +337,10 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 							SearchedBy: CPEParameters{
 								CPEs:      []string{"cpe:2.3:*:*:activerecord:4.0.1:*:*:*:*:*:*:*"},
 								Namespace: "nvd:cpe",
+								Package: CPEPackageParameter{
+									Name:    "activerecord",
+									Version: "4.0.1",
+								},
 							},
 							Found: CPEResult{
 								CPEs:              []string{"cpe:2.3:*:activerecord:activerecord:4.0.1:*:*:*:*:*:*:*"},
@@ -378,6 +394,10 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 							SearchedBy: CPEParameters{
 								CPEs:      []string{"cpe:2.3:*:awesome:awesome:98SE1:rando1:*:ra:*:dunno:*:*"},
 								Namespace: "nvd:cpe",
+								Package: CPEPackageParameter{
+									Name:    "awesome",
+									Version: "98SE1",
+								},
 							},
 							Found: CPEResult{
 								CPEs:              []string{"cpe:2.3:*:awesome:awesome:*:*:*:*:*:*:*:*"},
@@ -424,6 +444,10 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 							SearchedBy: CPEParameters{
 								CPEs:      []string{"cpe:2.3:*:multiple:multiple:1.0:*:*:*:*:*:*:*"},
 								Namespace: "nvd:cpe",
+								Package: CPEPackageParameter{
+									Name:    "multiple",
+									Version: "1.0",
+								},
 							},
 							Found: CPEResult{
 								CPEs: []string{
@@ -484,6 +508,10 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 							SearchedBy: CPEParameters{
 								CPEs:      []string{"cpe:2.3:*:sw:sw:*:*:*:*:*:*:*:*"},
 								Namespace: "nvd:cpe",
+								Package: CPEPackageParameter{
+									Name:    "sw",
+									Version: "0.1",
+								},
 							},
 							Found: CPEResult{
 								CPEs: []string{
@@ -536,6 +564,10 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 							SearchedBy: CPEParameters{
 								CPEs:      []string{"cpe:2.3:*:funfun:funfun:*:*:*:*:*:python:*:*"},
 								Namespace: "nvd:cpe",
+								Package: CPEPackageParameter{
+									Name:    "funfun",
+									Version: "5.2.1",
+								},
 							},
 							Found: CPEResult{
 								CPEs: []string{
@@ -583,6 +615,10 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 							SearchedBy: CPEParameters{
 								CPEs:      []string{"cpe:2.3:a:handlebarsjs:handlebars:*:*:*:*:*:*:*:*"},
 								Namespace: "nvd:cpe",
+								Package: CPEPackageParameter{
+									Name:    "handlebars",
+									Version: "0.1",
+								},
 							},
 							Found: CPEResult{
 								CPEs: []string{
@@ -629,6 +665,10 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 							SearchedBy: CPEParameters{
 								CPEs:      []string{"cpe:2.3:a:handlebarsjs:handlebars:*:*:*:*:*:*:*:*"},
 								Namespace: "nvd:cpe",
+								Package: CPEPackageParameter{
+									Name:    "handlebars",
+									Version: "0.1",
+								},
 							},
 							Found: CPEResult{
 								CPEs: []string{
