@@ -6,12 +6,14 @@ import (
 	"github.com/wagoodman/go-partybus"
 
 	grypeEvent "github.com/anchore/grype/grype/event"
+	"github.com/anchore/grype/grype/event/parsers"
 	"github.com/anchore/grype/internal/log"
 )
 
 type loggerUI struct {
 	unsubscribe  func() error
 	reportOutput io.Writer
+	reports      []string
 }
 
 // NewLoggerUI writes all events to the common application logger and writes the final report to the given writer.
@@ -26,25 +28,28 @@ func (l *loggerUI) Setup(unsubscribe func() error) error {
 	return nil
 }
 
-func (l loggerUI) Handle(event partybus.Event) error {
+func (l *loggerUI) Handle(event partybus.Event) error {
 	switch event.Type {
-	case grypeEvent.VulnerabilityScanningFinished:
-		if err := handleVulnerabilityScanningFinished(event, l.reportOutput); err != nil {
-			log.Warnf("unable to show catalog image finished event: %+v", err)
+	case grypeEvent.CLIReport:
+		_, report, err := parsers.ParseCLIReport(event)
+		if err != nil {
+			log.Errorf("unable to show %s event: %+v", event.Type, err)
+			break
 		}
-	case grypeEvent.NonRootCommandFinished:
-		if err := handleNonRootCommandFinished(event, l.reportOutput); err != nil {
-			log.Warnf("unable to show command finished event: %+v", err)
-		}
-	// ignore all events except for the final events
-	default:
-		return nil
+		l.reports = append(l.reports, report)
+	case grypeEvent.CLIExit:
+		// this is the last expected event, stop listening to events
+		return l.unsubscribe()
 	}
-
-	// this is the last expected event, stop listening to events
-	return l.unsubscribe()
+	return nil
 }
 
 func (l loggerUI) Teardown(_ bool) error {
+	for _, report := range l.reports {
+		_, err := l.reportOutput.Write([]byte(report))
+		if err != nil {
+			return err
+		}
+	}
 	return nil
 }
