@@ -16,7 +16,7 @@ import (
 	"github.com/anchore/grype/grype/pkg"
 	"github.com/anchore/grype/grype/store"
 	"github.com/anchore/grype/grype/vulnerability"
-	"github.com/anchore/grype/internal"
+	"github.com/anchore/grype/internal/stringutil"
 	"github.com/anchore/stereoscope/pkg/imagetest"
 	"github.com/anchore/syft/syft"
 	syftPkg "github.com/anchore/syft/syft/pkg"
@@ -538,8 +538,8 @@ func addHaskellMatches(t *testing.T, theSource source.Source, catalog *syftPkg.C
 }
 
 func TestMatchByImage(t *testing.T) {
-	observedMatchers := internal.NewStringSet()
-	definedMatchers := internal.NewStringSet()
+	observedMatchers := stringutil.NewStringSet()
+	definedMatchers := stringutil.NewStringSet()
 	for _, l := range match.AllMatcherTypes {
 		definedMatchers.Add(string(l))
 	}
@@ -606,13 +606,15 @@ func TestMatchByImage(t *testing.T) {
 
 			userImage := "docker-archive:" + tarPath
 
-			sourceInput, err := source.ParseInput(userImage, "")
+			detection, err := source.Detect(userImage, source.DetectConfig{})
 			require.NoError(t, err)
 
 			// this is purely done to help setup mocks
-			theSource, cleanup, err := source.New(*sourceInput, nil, nil)
+			theSource, err := detection.NewSource(source.DetectionSourceConfig{})
 			require.NoError(t, err)
-			defer cleanup()
+			t.Cleanup(func() {
+				require.NoError(t, theSource.Close())
+			})
 
 			// TODO: relationships are not verified at this time
 			config := cataloger.DefaultConfig()
@@ -645,7 +647,7 @@ func TestMatchByImage(t *testing.T) {
 			}
 
 			// build expected matches from what's discovered from the catalog
-			expectedMatches := test.expectedFn(*theSource, collection, theStore)
+			expectedMatches := test.expectedFn(theSource, collection, theStore)
 
 			assertMatches(t, expectedMatches.Sorted(), actualResults.Sorted())
 		})
